@@ -11,6 +11,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+
 #include "kalziumglwidget.h"
 
 #include <QSettings>
@@ -38,10 +39,8 @@ KalziumGLWidget::KalziumGLWidget(QWidget *parent) : Avogadro::GLWidget(parent),
     // first set the Avogadro plugin directory,
     // avoiding overwriting an already set envvar
     static bool s_pluginDirSet = false;
-    if (!s_pluginDirSet)
-    {
-        if (qgetenv("AVOGADRO_PLUGINS").isEmpty())
-        {
+    if (!s_pluginDirSet) {
+        if (qgetenv("AVOGADRO_PLUGINS").isEmpty()) {
             qputenv("AVOGADRO_PLUGINS", AVOGADRO_PLUGIN_DIR);
         }
         s_pluginDirSet = true;
@@ -70,33 +69,32 @@ KalziumGLWidget::~KalziumGLWidget()
 
 bool KalziumGLWidget::openFile(const QString &file)
 {
-    Avogadro::Molecule* mol = OpenBabel2Wrapper::readMolecule( file );
-    if (!mol)
+    Avogadro::Molecule* mol = OpenBabel2Wrapper::readMolecule(file);
+    if (!mol) {
         return false;
+    }
     Avogadro::Molecule* oldmol = molecule();
-    if (oldmol)
+    if (oldmol) {
         oldmol->deleteLater();
-    setMolecule( mol );
+    }
+    setMolecule(mol);
     update();
     return true;
 }
 
-void KalziumGLWidget::setStyle( int style )
+void KalziumGLWidget::setStyle(int style)
 {
-    foreach(Avogadro::Engine *engine, engines())
-    {
-        if((m_lastEngine1 == 0 && engine->identifier() == "Ball and Stick")
-           || (m_lastEngine1 == 1 && engine->identifier() == "Stick")
-           || (m_lastEngine1 == 2 && engine->identifier() == "Van der Waals Spheres")
-           || (m_lastEngine1 == 3 && engine->identifier() == "Wireframe"))
-        {
+    foreach (Avogadro::Engine *engine, engines()) {
+        if ((m_lastEngine1 == 0 && engine->identifier() == "Ball and Stick")
+            || (m_lastEngine1 == 1 && engine->identifier() == "Stick")
+            || (m_lastEngine1 == 2 && engine->identifier() == "Van der Waals Spheres")
+            || (m_lastEngine1 == 3 && engine->identifier() == "Wireframe")) {
             engine->setEnabled(false);
         }
-        if((style == 0 && engine->identifier() == "Ball and Stick")
-           || (style == 1 && engine->identifier() == "Stick")
-           || (style == 2 && engine->identifier() == "Van der Waals Spheres")
-           || (style == 3 && engine->identifier() == "Wireframe"))
-        {
+        if ((style == 0 && engine->identifier() == "Ball and Stick")
+            || (style == 1 && engine->identifier() == "Stick")
+            || (style == 2 && engine->identifier() == "Van der Waals Spheres")
+            || (style == 3 && engine->identifier() == "Wireframe")) {
             engine->setEnabled(true);
         }
     }
@@ -104,20 +102,17 @@ void KalziumGLWidget::setStyle( int style )
     update();
 }
 
-void KalziumGLWidget::setStyle2( int style )
+void KalziumGLWidget::setStyle2(int style)
 {
-    foreach(Avogadro::Engine *engine, engines())
-    {
-        if((m_lastEngine2 == 1 && engine->identifier() == "Ribbon")
-           || (m_lastEngine2 == 2 && engine->identifier() == "Ring")
-           || (m_lastEngine2 == 3 && engine->identifier() == "Orbitals"))
-        {
+    foreach (Avogadro::Engine *engine, engines()) {
+        if ((m_lastEngine2 == 1 && engine->identifier() == "Ribbon")
+            || (m_lastEngine2 == 2 && engine->identifier() == "Ring")
+            || (m_lastEngine2 == 3 && engine->identifier() == "Orbitals")) {
             engine->setEnabled(false);
         }
-        if((style == 1 && engine->identifier() == "Ribbon")
-           || (style == 2 && engine->identifier() == "Ring")
-           || (style == 3 && engine->identifier() == "Orbitals"))
-        {
+        if ((style == 1 && engine->identifier() == "Ribbon")
+            || (style == 2 && engine->identifier() == "Ring")
+            || (style == 3 && engine->identifier() == "Orbitals")) {
             engine->setEnabled(true);
         }
     }
@@ -127,46 +122,46 @@ void KalziumGLWidget::setStyle2( int style )
 
 void KalziumGLWidget::setLabels(int style)
 {
-  // Use the QSettings framework to configure the label engine
-  foreach(Avogadro::Engine *engine, engines())
-  {
-    if(engine->name() == "Label")
-    {
-      QSettings settings;
-      int atomType = 0;
-      int bondType = 0;
-      bool enabled = false;
-      // We need to use 
-      switch(style)
-      {
-        case 0: // Display no labels
-          enabled = false;
-          break;
-        case 1: // Display the atom symbol
-          enabled = true;
-          atomType = 3;
-          break;
-        case 2: // Display the atom name
-          enabled = true;
-          atomType = 2;
-          break;
-        default:
-          engine->setEnabled(false);
-      }
-      settings.setValue("atomLabel", atomType);
-      settings.setValue("bondLabel", bondType);
-      settings.setValue("enabled", enabled);
-      engine->readSettings(settings);
+    // Use the QSettings framework to configure the label engine
+    foreach (Avogadro::Engine *engine, engines()) {
+        if (engine->name() == "Label") {
+            QSettings settings;
+            int atomType = 0;
+            int bondType = 0;
+            bool enabled = false;
+            // We need to use 
+            switch(style) {
+            case 0: // Display no labels
+                enabled = false;
+                break;
+            case 1: // Display the atom symbol
+                enabled = true;
+                atomType = 3;
+                break;
+            case 2: // Display the atom name
+                enabled = true;
+                atomType = 2;
+                break;
+            default:
+                engine->setEnabled(false);
+            }
+            settings.setValue("atomLabel", atomType);
+            settings.setValue("bondLabel", bondType);
+            settings.setValue("enabled", enabled);
+            engine->readSettings(settings);
+        }
     }
-  }
 }
 
 void KalziumGLWidget::setQuality(int quality)
 {
     // Set the global quality of the GLWidget, 0=min, 2=mid, 4=max
     int q = 0;
-    if(quality == 1) q = 2;
-    else if(quality == 2) q = 4;
+    if (quality == 1) {
+        q = 2;
+    } else if (quality == 2) {
+        q = 4;
+    }
     GLWidget::setQuality(q);
     invalidateDLs();
     GLWidget::update();
